/**
 * Copyright (C) 2009, 2010 SC 4ViewSoft SRL
 *  
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *  
 *      http://www.apache.org/licenses/LICENSE-2.0
 *  
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.projektarbeit.graph;

import org.achartengine.chart.PointStyle;
import org.achartengine.renderer.XYMultipleSeriesRenderer;
import org.achartengine.renderer.XYSeriesRenderer;

import android.graphics.Color;
import android.graphics.Paint.Align;

/**
 * An abstract class for the demo charts to extend. It contains some methods for
 * building datasets and renderers.
 */
public abstract class AbstractChart {

	protected void setRenderer(XYMultipleSeriesRenderer renderer, int[] colors, PointStyle[] styles) {
	    renderer.setAxisTitleTextSize(16);
	    renderer.setChartTitleTextSize(20);
	    renderer.setLabelsTextSize(15);
	    renderer.setLegendTextSize(15);
	    renderer.setPointSize(5f);
	    renderer.setMargins(new int[] { 20, 30, 15, 20 });
	    int length = colors.length;
	    for (int i = 0; i < length; i++) {
	      XYSeriesRenderer r = new XYSeriesRenderer();
	      r.setColor(colors[i]);
	      r.setPointStyle(styles[i]);
	      renderer.addSeriesRenderer(r);
	    }
	  }

	  /**
	   * Sets a few of the series renderer settings.
	   * 
	   * @param renderer the renderer to set the properties to
	   * @param title the chart title
	   * @param xTitle the title for the X axis
	   * @param yTitle the title for the Y axis
	   * @param xMin the minimum value on the X axis
	   * @param xMax the maximum value on the X axis
	   * @param yMin the minimum value on the Y axis
	   * @param yMax the maximum value on the Y axis
	   * @param axesColor the axes color
	   * @param labelsColor the labels color
	   */
	  protected void setChartSettings(XYMultipleSeriesRenderer renderer, int colors[]) {
	    
		renderer.setLabelsTextSize(20);
		  
	    renderer.setXTitle("Time [s]");
	    renderer.setXLabelsAlign(Align.RIGHT);
	    renderer.setXLabelsColor(Color.LTGRAY);
	    renderer.setXLabels(10);
	    
	    renderer.setYLabels(10);
	    
	    renderer.setAxesColor(Color.LTGRAY);
	    renderer.setZoomButtonsVisible(true);
	    renderer.setPanLimits(new double[] { 0, 1000, 0, 300 });
	    renderer.setPanEnabled(true, false);
	    renderer.setZoomLimits(new double[] { 0, 1000, -50 , 300 });
	    renderer.setZoomRate(1.05f);
	    
 //	    renderer.setShowGrid(true);
	    
	    //Line1
	    renderer.setYTitle("Geschwindigkeit [km/h]");
	    renderer.setYLabelsAlign(Align.LEFT);
	    renderer.setYAxisMin(0);
	    renderer.setYAxisMax(300);
	    
	    	    
	    //Line2
	    renderer.setYTitle("Drehzahl [1/min]          Gang [1/1000]", 1);
	    renderer.setYAxisAlign(Align.RIGHT, 1);
	    renderer.setYLabelsAlign(Align.RIGHT, 1);
	    renderer.setYAxisMin(0, 1);
	    renderer.setYAxisMax(8000, 1);
	    

	    
	  }

	  /**
	   * Builds an XY multiple time dataset using the provided values.
	   * 
	   * @param titles the series titles
	   * @param xValues the values for the X axis
	   * @param yValues the values for the Y axis
	   * @return the XY multiple time dataset
	   */
	  

}
